@@ -1,11 +1,13 @@
 #include "TxtReader.h"
-TxtReader::TxtReader(QWidget * parent)
+//#include <QDebug>
+TxtReader::TxtReader(QWidget * parent,QString infile)
 	:QWidget(parent)
 {
 	//w1 = 0;
-	version = QString(tr("0.4.4"));
+	version = QString("0.5.2");
 	setWindowTitle( QString(tr("TXT Reader %1 --- By lsyer")).arg(version));
 	qApp->installTranslator(&appTranslator);
+	setAcceptDrops(true);
 	
     QSettings settings("lsyer", "txtreader");
 	QPoint pos = settings.value("pos", QPoint(100, 60)).toPoint();
@@ -26,18 +28,24 @@ TxtReader::TxtReader(QWidget * parent)
 		connect(bookmark, SIGNAL(triggered()), this, SLOT(openBookmark()));
 		bookmarkArray[settings.value(tr("bookmark%1index").arg(k)/*, 1*/).toInt()] = bookmark;
 	}
-	if(o_isfullscreen)
-		showFullScreen();
-	else{
-		resize(size);
-		move(pos);
-	}
 
 	createActions();
 	createLanguageMenu();
 	createTrayIcon();
 	setStyleSheet( "TxtReader {background-color: "+bgColor.name()+";background-image: url("+bgImage+");background-position:center;;}");
 	doc.setDefaultFont(txtFont);
+	
+	if(o_isfullscreen){
+		viewfullscreenAction->setEnabled(false);
+		nofullscreenAction->setEnabled(true);
+		showFullScreen();
+	}else{
+		viewfullscreenAction->setEnabled(true);
+		nofullscreenAction->setEnabled(false);
+		resize(size);
+		move(pos);
+	}
+	restoreAction->setEnabled(false);
 
 	connect(trayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
             this, SLOT(iconActivated(QSystemTrayIcon::ActivationReason)));
@@ -60,7 +68,11 @@ TxtReader::TxtReader(QWidget * parent)
 	
     appTranslator.load(":/i18n/txtreader_" + uilang);
 	retranslateUi();
-	loadFile(curFile);
+	//qDebug()<<"infile2:"<< infile <<"\n";
+	if(infile.isEmpty())
+		loadFile(curFile);
+	else
+		loadFile(infile);
 }
 
 void TxtReader::resizeEvent(QResizeEvent *)
@@ -89,11 +101,15 @@ int TxtReader::loadFile(const QString &fileName)
 	if (fileName.isEmpty()) {
 		showinstruction();
 		return 1;
+    }
+    if (curFile!=fileName) {
+		qDeleteAll(bookmarkArray);
+		bookmarkArray.clear();
+        setindex(1);
     }
 	QFile file(fileName);
 	if (!file.open(QFile::ReadOnly | QFile::Text)) {
 		showinstruction();
-		setindex(1);
 		return 1;
     }
 
@@ -108,7 +124,23 @@ int TxtReader::loadFile(const QString &fileName)
 	//statusBar()->showMessage(tr("File loaded"), 2000);
 	return 1;
 }
-void TxtReader::showinstruction(){	
+
+void TxtReader::readOrInstruction(){
+	static int i = 0;
+	static int page;
+	i = ++i % 2;
+	if(i){
+		page = index;
+		showinstruction();
+		instructionAct->setText(tr("&Go Back"));
+	}else{
+		loadFile(curFile);
+		setindex(page);
+		instructionAct->setText(tr("&Instruction"));
+	}
+}
+
+void TxtReader::showinstruction(){
 	QFile file(QString(":/README_%1.HTML").arg(uilang));
 	if (!file.open(QFile::ReadOnly | QFile::Text)) {
 		QMessageBox::warning(this, QString("TxtReader %1").arg(version),
@@ -119,6 +151,7 @@ void TxtReader::showinstruction(){
 	QTextStream in(&file);
 	in.setCodec("UTF-8");
 	doc.setHtml(in.readAll());
+	setindex(1);
 }
 void TxtReader::createActions()
 {
@@ -189,7 +222,7 @@ void TxtReader::createActions()
     viewfullscreenAction = new QAction(QIcon(":/images/fullscreen.png"),"", this);
     connect(viewfullscreenAction, SIGNAL(triggered()), this, SLOT(myshowfullscreen()));
     
-    nofullscreenAction = new QAction(QIcon(":/images/fullscreen.png"),"", this);
+    nofullscreenAction = new QAction(QIcon(":/images/nofullscreen.png"),"", this);
     connect(nofullscreenAction, SIGNAL(triggered()), this, SLOT(myexitfullscreen()));
     
     hiddenAction = new QAction(QIcon(":/images/min.png"),"", this);
@@ -210,7 +243,7 @@ void TxtReader::createActions()
     instructionAct = new QAction(QIcon(":/images/instruction.png"),"", this);
     //instructionAct->setShortcut(tr("Ctrl+A"));
     //instructionAct->setStatusTip(tr("Show the application's About box"));
-    connect(instructionAct, SIGNAL(triggered()), this, SLOT(showinstruction()));
+    connect(instructionAct, SIGNAL(triggered()), this, SLOT(readOrInstruction()));
 	return ;
 }
 
@@ -319,44 +352,39 @@ void TxtReader::setCurrentFile(const QString &fileName)
 
 void TxtReader::updateRecentFileActions()
 {
-    QSettings settings("lsyer", "txtreader");
-    QStringList files = settings.value("recentFileList").toStringList();
+	QSettings settings("lsyer", "txtreader");
+	QStringList files = settings.value("recentFileList").toStringList();
+	
+	int numRecentFiles = qMin(files.size(), (int)MaxRecentFiles);
+	
+	for (int i = 0; i < numRecentFiles; ++i) {
+		QString text = tr("&%1 %2").arg(i + 1).arg(strippedName(files[i]));
+		recentFileActs[i]->setText(text);
+		recentFileActs[i]->setData(files[i]);
+		recentFileActs[i]->setVisible(true);
+	}
+	for (int j = numRecentFiles; j < MaxRecentFiles; ++j)
+		recentFileActs[j]->setVisible(false);
 
-    int numRecentFiles = qMin(files.size(), (int)MaxRecentFiles);
-
-    for (int i = 0; i < numRecentFiles; ++i) {
-        QString text = tr("&%1 %2").arg(i + 1).arg(strippedName(files[i]));
-        recentFileActs[i]->setText(text);
-        recentFileActs[i]->setData(files[i]);
-        recentFileActs[i]->setVisible(true);
-    }
-    for (int j = numRecentFiles; j < MaxRecentFiles; ++j)
-        recentFileActs[j]->setVisible(false);
-
-    separatorAct->setVisible(numRecentFiles > 0);
+	separatorAct->setVisible(numRecentFiles > 0);
 	return ;
 }
 
 QString TxtReader::strippedName(const QString &fullFileName)
 {
-    return QFileInfo(fullFileName).fileName();
+	return QFileInfo(fullFileName).fileName();
 }
 
 void TxtReader::open()
 {
-    QString fileName = QFileDialog::getOpenFileName(this,tr("Open new file"),QFileInfo(curFile).dir().path(),tr("text files (*.txt)"));
-    if (!fileName.isEmpty() && curFile!=fileName) {
-		qDeleteAll(bookmarkArray);
-		bookmarkArray.clear();
-		loadFile(fileName);
-        setindex(1);
-    }
+	QString fileName = QFileDialog::getOpenFileName(this,tr("Open new file"),QFileInfo(curFile).dir().path(),tr("text files (*.txt)"));
+	loadFile(fileName);
 }
 void TxtReader::about()
 {
-	this->show();
-   QMessageBox::about(this, QString("TxtReader %1").arg(version),
-            QString(tr("<p align=center>Txt Reader（文本阅读器） %1 </p><p align=right> Design by <a href='http://lishao378.blog.sohu.com' target=_blank>lsyer</a><br>2008-5-5&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</p>")).arg(version));
+	//this->show();
+	QMessageBox::about(this, QString("TxtReader %1").arg(version),
+		QString(tr("<p align=center>Txt Reader %1 </p><p align=right> Design by <a href='http://lishao378.blog.sohu.com' target=_blank>lsyer</a></p><p align=center>CopyLeft(C)2006-2008</p>")).arg(version));
 	return ;
 }
 void TxtReader::setcodecstr(QAction *action)
@@ -498,25 +526,49 @@ void TxtReader::myhide()
 {
 	if(isHidden())
 		return;
+
 	o_isfullscreen = isFullScreen();
+	hiddenAction->setEnabled(false);
+	restoreAction->setEnabled(true);
    	hide();
 }
 void TxtReader::myrestore()
 {
-	if(o_isfullscreen)
+	if(o_isfullscreen){
 		showFullScreen();
-	else
+	}else{
 		show();
+	}
+
+	hiddenAction->setEnabled(true);
+	restoreAction->setEnabled(false);
 }
 void TxtReader::myshowfullscreen()
 {
+    QSettings settings("lsyer", "txtreader");
+	settings.setValue("pos", pos());
+	settings.setValue("size", size());
+	
 	o_isfullscreen = true;
-	showFullScreen();
+	viewfullscreenAction->setEnabled(false);
+	nofullscreenAction->setEnabled(true);
+	//showFullScreen();
+	myrestore();
 }
 void TxtReader::myexitfullscreen()
 {
+    QSettings settings("lsyer", "txtreader");
+	QPoint pos = settings.value("pos", QPoint(100, 60)).toPoint();
+	QSize size = settings.value("size", QSize(800, 600)).toSize();
+	
 	o_isfullscreen = false;
-	showMaximized();
+	viewfullscreenAction->setEnabled(true);
+	nofullscreenAction->setEnabled(false);
+	
+	//showMaximized();
+	resize(size);
+	move(pos);
+	myrestore();
 }
 
 void TxtReader::switchLanguage(QAction *action)
@@ -627,7 +679,11 @@ void TxtReader::keyPressEvent(QKeyEvent * event)
 }
 void TxtReader::mousePressEvent(QMouseEvent *event)
 {
-	if (event->button() == Qt::LeftButton) {
+	if(this->x()+3*this->width()/4< event->globalX() && event->globalX() < this->x()+this->width()){
+		setindex(index + 1);
+	}else if(this->x()< event->globalX() && event->globalX() < this->x()+this->width()/4){
+		setindex(index - 1);
+	}else if (event->button() == Qt::LeftButton) {
 		dragPosition = event->globalPos() - frameGeometry().topLeft();
 		event->accept();
 	}
@@ -656,6 +712,23 @@ void TxtReader::closeEvent ( QCloseEvent * event )
 	hideAndRestore();
 	event->ignore();
 }
+
+void TxtReader::dragEnterEvent(QDragEnterEvent *event)
+{
+	event->acceptProposedAction();
+}
+
+void TxtReader::dropEvent(QDropEvent *event)
+{
+	QList<QUrl> urls = event->mimeData()->urls();
+	if (urls.isEmpty())
+		return;
+	QString fileName = urls.first().toLocalFile();
+	if (fileName.isEmpty())
+		return;
+	loadFile(fileName);
+}
+
 void TxtReader::paintEvent(QPaintEvent *)
 {
     QStyleOption opt;
