@@ -4,9 +4,9 @@ int main(int argc,char ** argv)
 {
 	QApplication app(argc,argv);
 	QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
-	TxtReader * txtReader = new TxtReader;
+	TxtReader * txtReader = new TxtReader(0,argv[1]);
 	//txtReader->setWindowFlags(Qt::FramelessWindowHint);
-	//txtReader->setWindowTitle(QObject::tr("TXT Reader 0.3.2 --- By lsyer"));
+	//txtReader->setWindowTitle(QObject::tr("TXT Reader --- By lsyer"));
 	txtReader->setMinimumSize(200,150);
 	//txtReader->setMaximumSize(1000,750);
 	//txtReader->resize(800,600);
